"use client";
import { useState, useEffect } from "react";
import { useDebouncedCallback } from "use-debounce";
import PropTypes from "prop-types";
import Icons from "@components/base/icons";
import styles from "./styles.module.css";

const Search = ({ onSearch, onClose }) => {
  const [text, setText] = useState("");

  const handleDebounceChange = useDebouncedCallback((value) => {
    onSearch(value);
  }, 1000);
  const handleInputChange = (value) => {
    setText(value);
    handleDebounceChange(value);
  };

  const handleCustomClear = (e) => {
    e.preventDefault();
    onClose("");
    setText("");
  };

  return (
    <div className={styles["search"]}>
      <span className={`${styles["search-icon"]}`}>
        <Icons name="search" size="small" />
      </span>
      <input
        className={styles["search-input"]}
        type="text"
        autoFocus={true}
        value={text}
        onChange={(e) => handleInputChange(e.target.value)}
        placeholder="Discover news, articles and more"
      />
      {text && (
        <span className={`${styles["close-icon"]}`} onClick={handleCustomClear}>
          <Icons name="close" size="small" />
        </span>
      )}
    </div>
  );
};

Search.propTypes = {
  onSearch: PropTypes.func,
  onClose: PropTypes.func,
};
export default Search;
